@@ -28,20 +28,15 @@
 #include "sidebar.h"
 #include "networkmanager.h"
 #include "../config.h"
-#include "desktopfile.h"
 
 #include <QSettings>
+#include <QFile>
 
 VerticalTabsPlugin::VerticalTabsPlugin()
     : QObject()
 {
 }
 
-DesktopFile VerticalTabsPlugin::metaData() const
-{
-    return DesktopFile(QSL(":verticaltabs/metadata.desktop"));
-}
-
 void VerticalTabsPlugin::init(InitState state, const QString &settingsPath)
 {
     m_settingsPath = settingsPath + QL1S("/extensions.ini");
@@ -96,7 +91,7 @@ bool VerticalTabsPlugin::testPlugin()
 
 void VerticalTabsPlugin::showSettings(QWidget *parent)
 {
-    VerticalTabsSettings *settings = new VerticalTabsSettings(this, parent);
+    auto *settings = new VerticalTabsSettings(this, parent);
     settings->exec();
 }
 
@@ -124,7 +119,7 @@ void VerticalTabsPlugin::setViewType(ViewType type)
     QSettings settings(m_settingsPath, QSettings::IniFormat);
     settings.setValue(QSL("VerticalTabs/ViewType"), m_viewType);
 
-    emit viewTypeChanged(m_viewType);
+    Q_EMIT viewTypeChanged(m_viewType);
 }
 
 bool VerticalTabsPlugin::replaceTabBar() const
@@ -217,5 +212,5 @@ void VerticalTabsPlugin::loadStyleSheet(const QString &theme)
     }
 
     m_styleSheet = QString::fromUtf8(file.readAll());
-    emit styleSheetChanged(m_styleSheet);
+    Q_EMIT styleSheetChanged(m_styleSheet);
 }
